package com.foreverwin.mesnac.common.controller;

import com.foreverwin.modular.core.util.R;
import com.foreverwin.modular.core.util.FrontPage;
import com.foreverwin.modular.core.util.CommonMethods;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.foreverwin.mesnac.common.service.PrintLogService;
import com.foreverwin.mesnac.common.model.PrintLog;
import java.util.List;

/**
 *
 * @author Philip
 * @since 2021-07-16
 */
@RestController
@RequestMapping("/Z-PRINT-LOG")
public class PrintLogController {

    @Autowired
    public PrintLogService printLogService;

    /**
    * 根据id查询
    *
    * @param id 主键
    * @return
    */
    @ResponseBody
    @GetMapping("/{id:.+}")
    public R getPrintLogById(@PathVariable String id) {
        return R.ok( printLogService.getById(id));
    }

    /**
     * 查询所有数据
     *
     * @return
     */
    @ResponseBody
    @GetMapping("")
    public R getPrintLogList(PrintLog printLog){
        List<PrintLog> result;
        QueryWrapper<PrintLog> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(printLog);
        result = printLogService.list(queryWrapper);
        return R.ok(result);
    }

    /**
     * 分页查询数据
     *
     * @param frontPage  分页信息
     * @return
     */
    @ResponseBody
    @GetMapping("/page")
    public R page(FrontPage<PrintLog> frontPage, PrintLog printLog){
        IPage result;
        QueryWrapper<PrintLog> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(printLog);
        if (frontPage.getGlobalQuery() != null && !"".equals(frontPage.getGlobalQuery().trim())) {
            //TODO modify global query
            queryWrapper.lambda().and(wrapper -> wrapper
                .like(PrintLog::getHandle, frontPage.getGlobalQuery())
                .or().like(PrintLog::getSite, frontPage.getGlobalQuery())
                .or().like(PrintLog::getCategory, frontPage.getGlobalQuery())
                .or().like(PrintLog::getPrintName, frontPage.getGlobalQuery())
                .or().like(PrintLog::getPrintTemplate, frontPage.getGlobalQuery())
                .or().like(PrintLog::getPrintParam, frontPage.getGlobalQuery())
                .or().like(PrintLog::getSfc, frontPage.getGlobalQuery())
                .or().like(PrintLog::getResrce, frontPage.getGlobalQuery())
                .or().like(PrintLog::getStepId, frontPage.getGlobalQuery())
                .or().like(PrintLog::getOperation, frontPage.getGlobalQuery())
                .or().like(PrintLog::getInventory, frontPage.getGlobalQuery())
                .or().like(PrintLog::getComments, frontPage.getGlobalQuery())
                .or().like(PrintLog::getOther1, frontPage.getGlobalQuery())
                .or().like(PrintLog::getOther2, frontPage.getGlobalQuery())
                .or().like(PrintLog::getOther3, frontPage.getGlobalQuery())
                .or().like(PrintLog::getOther4, frontPage.getGlobalQuery())
                .or().like(PrintLog::getOther5, frontPage.getGlobalQuery())
                .or().like(PrintLog::getCreateUser, frontPage.getGlobalQuery())
                .or().like(PrintLog::getModifyUser, frontPage.getGlobalQuery())
    );
        }
        result = printLogService.page(frontPage.getPagePlus(), queryWrapper);
        return R.ok(result);
    }

    /**
     * 新增
     * @param printLog  传递的实体
     * @return  null 失败  实体成功
     */
    @PostMapping
    public R save(@RequestBody PrintLog printLog) {
        return R.ok(printLogService.save(printLog));
    }

    /**
     * 修改
     * @param printLog  传递的实体
     * @return  null 失败  实体成功
     */
    @PutMapping
    public R updateById(@RequestBody PrintLog printLog) {
        return R.ok(printLogService.updateById(printLog));
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     * @return 0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.DELETE, value = "/{id:.+}")
    public R removeById(@PathVariable("id") String id){
        return R.ok(printLogService.removeById(id));
    }

    /**
     * 批量删除对象
     * @param ids 实体集合ID
     * @return  0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.POST, value = "/delete-batch")
    public R removeByIds(List<String> ids){
        return R.ok(printLogService.removeByIds(ids));
    }
}